@@ -57,7 +57,7 @@ our @EXPORT = qw(
 	tokenizer_destroy
 );
 
-our $VERSION = '0.2.3';
+our $VERSION = '0.2.4';
 
 sub AUTOLOAD {
     # This AUTOLOAD is used to 'autoload' constants from the constant()
@@ -338,7 +338,7 @@ This tokenizer is based on code generated by B<flex> - fast lexical analyzer gen
 
 =head1 AUTHOR
 
-Samuel Behan, E<lt>sam@frida.fri.utc.skE<gt>
+Samuel Behan, E<lt>sam(at)frida.fri.utc.skE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
